﻿using System;
using System.Drawing;
using System.Windows.Forms;
using IWshRuntimeLibrary;
using System.IO;

namespace SciLor_s_Mashed_Runner {
    public partial class frmMashed : Form {
        public frmMashed() {
            InitializeComponent();

            cmbLanguage.SelectedIndexChanged -= new System.EventHandler(this.cmbLanguage_SelectedIndexChanged);
            cmbIcon.SelectedIndexChanged -= new System.EventHandler(this.cmbIcon_SelectedIndexChanged);


            cmbLanguage.Items.Add(new Language("English", "English", 0));
            cmbLanguage.Items.Add(new Language("Français", "French", 1));
            cmbLanguage.Items.Add(new Language("Deutsch", "German", 2));
            cmbLanguage.Items.Add(new Language("Español", "Spanish", 3));
            cmbLanguage.Items.Add(new Language("Português", "Portuguese", 4));

            cmbLanguage.SelectedIndex = Properties.Settings.Default.Language;
            if (Properties.Settings.Default.Path.Length == 0)
                Properties.Settings.Default.Path = Util.GetExeDir() + "\\";
            txtPath.Text = Util.GetMashedDir();
            txtPath.Text += Mashed.EXE;

            for (int i = 0; i < Mashed.ICOS.Length; i++) {
                IconFile icon = Mashed.ICOS[i];
                cmbIcon.Items.Add(icon);
            }

            if (Properties.Settings.Default.Icon.Length == 0) {
                Properties.Settings.Default.Icon = Mashed.ICO;
            }
            foreach (Object obj in cmbIcon.Items) {
                if (obj.Equals(new IconFile(Properties.Settings.Default.Icon))) {
                    cmbIcon.SelectedItem = obj;
                }
            }

            loadICO();
            setIntroState();


            cmbLanguage.SelectedIndexChanged += new System.EventHandler(this.cmbLanguage_SelectedIndexChanged);
            cmbIcon.SelectedIndexChanged += new System.EventHandler(this.cmbIcon_SelectedIndexChanged);
        }

        private void btnRunMashed_Click(object sender, EventArgs e) {
            Mashed.Run(false, false, true, this);
        }

        private void btnRunVideo_Click(object sender, EventArgs e) {
            Mashed.Run(true, false, false, this);
        }

        private void btnRunController_Click(object sender, EventArgs e) {
            Mashed.Run(false, true, false, this);
        }

        private void cmbLanguage_SelectedIndexChanged(object sender, EventArgs e) {
            Properties.Settings.Default.Language = cmbLanguage.SelectedIndex;
            Properties.Settings.Default.Save();
        }

        private void btnPath_Click(object sender, EventArgs e) {
            OpenFileDialog ofd = new OpenFileDialog();
            ofd.Filter = Mashed.EXE + "|" + Mashed.EXE;
            ofd.CheckFileExists = true;
            ofd.FileName = Mashed.EXE;

            if (ofd.ShowDialog() == System.Windows.Forms.DialogResult.OK) {
                if (ofd.FileName.EndsWith(Mashed.EXE)) {
                    txtPath.Text = ofd.FileName;
                    Properties.Settings.Default.Path = txtPath.Text.Remove(txtPath.TextLength - Mashed.EXE.Length);
                    Properties.Settings.Default.Save();
                    loadICO();
                    setIntroState();
                }
            }
        }

        private void btnShortcut_Click(object sender, EventArgs e) {
            SaveFileDialog sfd = new SaveFileDialog();
            sfd.DefaultExt = ".lnk";
            sfd.FileName = "Mashed Fully Loaded.lnk";
            sfd.Filter = "Shortcut (*.lnk)|*.lnk";
            sfd.ValidateNames = true;
            if (sfd.ShowDialog() == System.Windows.Forms.DialogResult.OK && sfd.FileName != null) {
                WshShellClass wshShell = new WshShellClass();
                IWshShortcut link = (IWshShortcut)(wshShell.CreateShortcut(sfd.FileName));
                link.TargetPath = Util.GetExePath();
                link.Arguments = "-r";
                link.Description = "Starts Mashed Fully Loaded";
                if (Mashed.checkExe()) 
                    link.IconLocation = Util.GetExeDir() + "\\" +
                        "icon" + cmbIcon.SelectedItem + ".ico";
                link.Save();
            }
        }

        private void cmbIcon_SelectedIndexChanged(object sender, EventArgs e) {
            Properties.Settings.Default.Icon = (cmbIcon.SelectedItem as IconFile).path;
            Properties.Settings.Default.Save();
            loadICO();
        }

        private void cmbIntro_SelectedIndexChanged(object sender, EventArgs e) {
            if ((String)cmbIntro.SelectedItem == "Enabled") {
                Intro.Enable();
            } else {
                Intro.Disable();
            }
            setIntroState();
        }



        private void setIntroState() {
            String path = Properties.Settings.Default.Path + Mashed.BASE_VIDEO_DIR + "backup";
            cmbIntro.SelectedIndexChanged -= new System.EventHandler(this.cmbIntro_SelectedIndexChanged);
            if (!System.IO.Directory.Exists(path)) {
                cmbIntro.SelectedItem = "Enabled";
            } else {
                cmbIntro.SelectedItem = "Disabled";
            }
            cmbIntro.SelectedIndexChanged += new System.EventHandler(this.cmbIntro_SelectedIndexChanged);

        }
        private void loadICO() {
            String path = Util.GetMashedDir() + Properties.Settings.Default.Icon;
            if (!System.IO.File.Exists(path)) {
                return;
            }

            btnRunMashed.Image = new Bitmap(path);
            btnRunVideo.Image = btnRunMashed.Image;
            btnRunController.Image = btnRunMashed.Image;

            btnRunMashed.ImageAlign = ContentAlignment.TopLeft;
            btnRunVideo.ImageAlign = ContentAlignment.MiddleLeft;
            btnRunController.ImageAlign = ContentAlignment.BottomLeft;

            this.ShowIcon = false;
            this.Icon = null;
            this.ShowIcon = true;
            this.Icon = Icon.FromHandle(new Bitmap(path).GetHicon());

            String iconPath = Util.GetExeDir() + "\\" +
                "icon" + cmbIcon.SelectedItem + ".ico";

            if (!System.IO.File.Exists(iconPath)) {
                FileStream fs = new FileStream(iconPath, FileMode.Create);
                this.Icon.Save(fs);
                fs.Close();
            }
        }
    }
}
